##############################################################################
# cmake configuration file for LArPandoraContent
#
# requires:
#   MacroCheckPackageLibs.cmake for checking package libraries
#
# returns following variables:
#
#   LArPandoraContent_FOUND      : set to TRUE if LArPandoraContent found
#       if FIND_PACKAGE called with REQUIRED and COMPONENTS arguments
#       LArPandoraContent_FOUND is only set to TRUE if ALL components are also found
#       if REQUIRED is NOT set components may or may not be available
#
#   LArPandoraContent_ROOT       : path to this LArPandoraContent installation
#   LArPandoraContent_VERSION    : package version
#   LArPandoraContent_LIBRARIES  : list of LArPandoraContent libraries (NOT including COMPONENTS)
#   LArPandoraContent_INCLUDE_DIRS  : list of paths to be used with INCLUDE_DIRECTORIES
#   LArPandoraContent_LIBRARY_DIRS  : list of paths to be used with LINK_DIRECTORIES
#   LArPandoraContent_COMPONENT_LIBRARIES      : list of LArPandoraContent component libraries
#   LArPandoraContent_${COMPONENT}_FOUND       : set to TRUE or FALSE for each library
#   LArPandoraContent_${COMPONENT}_LIBRARY     : path to individual libraries
#   LArPandoraContent_${COMPONENT}_LIB_DEPENDS : individual library dependencies
#
# @author Jan Engels, Desy
##############################################################################

SET( LArPandoraContent_ROOT "$ENV{LARPANDORACONTENT_FQ_DIR}" )
SET( LArPandoraContent_VERSION "02.03.00" )


# ---------- include dirs -----------------------------------------------------
# do not store find results in cache
SET( LArPandoraContent_INCLUDE_DIRS LArPandoraContent_INCLUDE_DIRS-NOTFOUND )
MARK_AS_ADVANCED( LArPandoraContent_INCLUDE_DIRS )

FIND_PATH( LArPandoraContent_INCLUDE_DIRS
	NAMES LArCheating/CheatingClusterCreationAlgorithm.h
	PATHS ${LArPandoraContent_ROOT}/include
	NO_DEFAULT_PATH
)



# ---------- libraries --------------------------------------------------------
INCLUDE( "/Users/macdev/workspace/larsoft-v04_25_00/OSX-10.10/debug/build/pandora/v02_03_00/Darwin64bit+14-nu-e7-debug/pandora-v02-03-00/cmakemodules/MacroCheckPackageLibs.cmake" )

# only standard libraries should be passed as arguments to CHECK_PACKAGE_LIBS
# additional components are set by cmake in variable PKG_FIND_COMPONENTS
# first argument should be the package name
CHECK_PACKAGE_LIBS( LArPandoraContent LArPandoraContent )




# ---------- libraries dependencies -------------------------------------------
# this sets LArPandoraContent_${COMPONENT}_LIB_DEPENDS variables
INCLUDE( "${LArPandoraContent_ROOT}/lib/cmake/LArPandoraContentLibDeps.cmake" )
 



# ---------- final checking ---------------------------------------------------
INCLUDE( FindPackageHandleStandardArgs )
# set LARPANDORACONTENTNEW_FOUND to TRUE if all listed variables are TRUE and not empty
# LArPandoraContent_COMPONENT_VARIABLES will be set if FIND_PACKAGE is called with REQUIRED argument
FIND_PACKAGE_HANDLE_STANDARD_ARGS( LArPandoraContent DEFAULT_MSG LArPandoraContent_ROOT LArPandoraContent_INCLUDE_DIRS LArPandoraContent_LIBRARIES ${LArPandoraContent_COMPONENT_VARIABLES} )

SET( LArPandoraContent_FOUND ${LARPANDORACONTENTNEW_FOUND} )

